<?php
// Responsive design support settings
function squaregrid_form_system_theme_settings_alter(&$form, &$form_state) {

// Fieldgroup
$form['responsive'] = array(
  '#type'   => 'fieldset',
  '#title'  => t('Responsive Design Settings'),
  '#description' => t('Select how you want your theme to behave in various browser window/screen sizes.'),
  '#weight' => '-20',
);

  // Checkbox to enable responsive support. Enabled is default
  $form['responsive']['responsive_support'] = array(
    '#type' => 'checkbox',
    '#title' => t('Support mobile-first responsive design?'),
    '#default_value' => theme_get_setting('responsive_support'),
    '#description' => t('<strong>Select</strong> this checkbox to configure responsive design support. <strong>Deselect</strong> if you want a single grid width setting for all displays. Additional configuration options are available, depending upon this setting.'),
  );

  // Field subgrouping - visible only for responsive options
  $form['responsive']['responsive_options'] = array(
    '#type'   => 'fieldset',
    '#title'  => t('Add Grid Width Support'),
    '#description' => t('<em>You have enabled responsive design support.</em><p>The largest grid enabled below that fits within the screen width will govern display. On screen widths smaller than the smallest enabled grid, pages are loaded in single-column display for readability. <em>If no grids are selected, no grid css will be loaded at all and everything will be single-column.</em><p><em>Note:</em> Some browsers, such as Internet Explorer 6-8, do not natively support the media queries utilized for responsive design. <em>See</em> the <a href="!link">Respond project on Github</a> for a JavaScript solution you can add to your site.</p><p><strong>Choose one or more grids to govern responsive display:</strong></p>', array('!link' => 'https://github.com/scottjehl/Respond')),
    '#states' => array(
      'invisible' => array(
        ':input[name="responsive_support"]' => array('checked' => FALSE),
      ),
    ),
  );

    // Checkbox to endable responsive 770px grid
    $form['responsive']['responsive_options']['smallgrid'] = array(
      '#type' => 'checkbox',
      '#title' => t('770px grid'),
      '#default_value' => theme_get_setting('smallgrid'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

    // Checkbox to endable responsive 980px grid
    $form['responsive']['responsive_options']['squaregrid'] = array(
      '#type' => 'checkbox',
      '#title' => t('980px grid [*recommended default]'),
      '#default_value' => theme_get_setting('squaregrid'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

    // Checkbox to endable responsive 1190px grid
    $form['responsive']['responsive_options']['sgw1190'] = array(
      '#type' => 'checkbox',
      '#title' => t('1190px grid'),
      '#default_value' => theme_get_setting('sgw1190'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

  $form['responsive']['static_options'] = array(
    '#type'   => 'fieldset',
    '#title'  => t('Select universal grid size'),
    '#description' => t('<em>You have disabled responsive design support.</em>'),
    '#states' => array(
      'invisible' => array(
        ':input[name="responsive_support"]' => array('checked' => TRUE),
        ),
    ),
  );

    $form['responsive']['static_options']['static_select'] = array(
      '#type' => 'radios',
      '#title' => t('Choose the grid to use for all screen sizes:'),
      '#options' => array(
        'static770'  => t('770px grid'),
        'static980'  => t('980px grid'),
        'static1190' => t('1190px grid'),
        ),
      '#default_value' => theme_get_setting('static_select'),
    );
      

// Theme development tools fieldset
  $form['gridoptions'] = array(
    '#type'   => 'fieldset',
    '#title'  => t('Theme Development Tools'),
    '#weight' => '-21',
    '#description' => t('These tools are <strong>not intended for lives sites</strong> and are provided for convenience only while you develop your theme.'),
  );

    // checkbox option to display the grid
    $form['gridoptions']['showgrid'] = array(
      '#type' => 'checkbox',
      '#title' => t('Display the grid'),
      '#default_value' => theme_get_setting('showgrid'),
      '#description' => t('While testing your own sub-theme layout, it can be helpful to display the grid.'),
    );

    // checkbox option to rebuild theme registry on every pageload
    $form['gridoptions']['squaregrid_rebuild_registry'] = array(
      '#type'          => 'checkbox',
      '#title'         => t('Rebuild theme registry on every pageload'),
      '#default_value' => theme_get_setting('squaregrid_rebuild_registry'),
      '#description'   => t('<strong>WARNING! This setting has a huge performance penalty! Remember to turn this off when your site goes live.</strong> <em>See <a href="!link">rebuild the theme registry</a> for more information on this</em>.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    );

}
